/**
 * (C) Le Hong Phuong, phuonglh@gmail.com
 */
package vn.hus.nlp.lexicon;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Properties;
import java.util.StringTokenizer;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;

import org.vietspider.common.io.LogService;
import org.vietspider.common.io.UtilFile;

import vn.hus.nlp.lexicon.jaxb.Corpus;

/**
 * @author Le Hong Phuong, phuonglh@gmail.com
 * <p>
 * A unmarshaller for lexicon.
 */
public class LexiconUnmarshaller {

  //vietspider update create context
	
	JAXBContext jaxbContext; 
	
	Unmarshaller unmarshaller;
	
	/**
	 * Default constructor.
	 */
	public LexiconUnmarshaller() {
		// create JAXB context
		//
		createContext();
	}
	
	private void createContext() {
		jaxbContext = null;
		try {
			jaxbContext = JAXBContext.newInstance(IConstants.PACKAGE_NAME, getClass().getClassLoader());
		} catch (JAXBException e) {
			LogService.getInstance().setThrowable(e);
		}
	}
	
	/**
	 * Get the marshaller object.
	 * @return the marshaller object
	 */
	public Unmarshaller getUnmarshaller() {
		if (unmarshaller == null) {
			try {
				// create the unmarshaller
				unmarshaller = jaxbContext.createUnmarshaller();
			} catch (JAXBException e) {
				LogService.getInstance().setThrowable(e);
			}
		}
		return unmarshaller;
	}

	/**
	 * Unmarshal a lexicon.
	 * @param filename a lexicon file
	 * @return a Corpus object.
	 */
	public Corpus unmarshal(String filename) {
//	  System.out.println(" file "+ filename);
		try {
		  File file = UtilFile.getFile("system/nlp/tokenizer", filename);
		  FileInputStream is = new FileInputStream(file);
//		  System.out.println("bebe "+ file.getAbsolutePath());
			Object object = getUnmarshaller().unmarshal(is);
			if (object instanceof Corpus) {
				Corpus corpus = (Corpus) object;
				return corpus;
			}
		} catch (Exception e) {
		  LogService.getInstance().setThrowable(e);
		}
		return null;
	}
	
}
